==> jc-1.4.0.tar.gz: gnu/java/rmi/server/ConnectionRunnerPool__24ConnectionRunner.h <==
// public class gnu.java.rmi.server.ConnectionRunnerPool$ConnectionRunner

// class file dependencies
// @dep_class eeab258a1c2e5f74 gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner_H_
#define _JC_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_server_UnicastConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_ThreadGroup$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object;

typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24rmi__24server__24ConnectionRunnerPool;
};
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$_init$79aa2c19ef50c886(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *, struct _jc_java_lang_ThreadGroup$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$dispatch$0462a98e299c9279(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$exit$18a14ad8b1514a1b(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$dispatch$0462a98e299c9279;
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$exit$18a14ad8b1514a1b;
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods {
	void	(*dispatch$0462a98e299c9279)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *);
	void	(*exit$18a14ad8b1514a1b)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *);
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *);
};

// Vtable
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods	gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner;
};

// Vtype
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs {
	struct _jc_gnu_java_rmi_server_UnicastConnection$object	*conn;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs {
    _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs	gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs {
	jboolean	volatile exiting;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs	gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object {
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype	*vtype;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$class_object;

#endif	/* _JC_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/ConnectionRunnerPool__24ConnectionRunner.h <==
// public class gnu.java.rmi.server.ConnectionRunnerPool$ConnectionRunner

// class file dependencies
// @dep_class eeab258a1c2e5f74 gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner_H_
#define _JC_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_server_UnicastConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_ThreadGroup$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object;

typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24rmi__24server__24ConnectionRunnerPool;
};
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$fields_struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$_init$79aa2c19ef50c886(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *, struct _jc_java_lang_ThreadGroup$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$dispatch$0462a98e299c9279(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$exit$18a14ad8b1514a1b(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$dispatch$0462a98e299c9279;
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$exit$18a14ad8b1514a1b;
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods {
	void	(*dispatch$0462a98e299c9279)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *) _JC_JCNI_ATTR;
	void	(*exit$18a14ad8b1514a1b)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *) _JC_JCNI_ATTR;
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vmethods	gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner;
};

// Vtype
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs {
	struct _jc_gnu_java_rmi_server_UnicastConnection$object	*conn;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs {
    _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_refs	gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs {
	jboolean	volatile exiting;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$sub_nonrefs	gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object {
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype	*vtype;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$vtype _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$class_object;

#endif	/* _JC_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner_H_ */
